package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.34.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.34.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`\P`!````X!\```````!``````````."3````
M````!0```$``.``*`$``&@`9``8````$````0`````````!``````````$``
M````````,`(````````P`@````````@``````````P````0```!P`@``````
M`'`"````````<`(````````A`````````"$``````````0`````````#``!P
M!````*V2`````````````````````````````#,````````````````````!
M``````````$````%````````````````````````````````````+(T`````
M```LC0`````````0`````````0````8```#8C0```````-B=````````V)T`
M``````"P!````````-@4`````````!`````````"````!@```/"-````````
M\)T```````#PG0```````!`"````````$`(````````(``````````0````$
M````E`(```````"4`@```````)0"````````1`````````!$``````````0`
M````````4.5T9`0```#HC````````.B,````````Z(P````````4````````
M`!0`````````!`````````!1Y71D!@``````````````````````````````
M```````````````````````````0`````````%+E=&0$````V(T```````#8
MG0```````-B=````````*`(````````H`@````````$`````````+VQI8B]L
M9"UL:6YU>"UR:7-C=C8T+6QP-C1D+G-O+C$`````!````!0````#````1TY5
M`,X./_ALCJL1F%(=8AJ.\M9)$"O=!````!`````!````1TY5```````$````
M#P`````````1````2`````0````(````()`0`05`!,0H`@$$@(8$A(()```)
M(`0(B(`00;H``H@`````2````$L```!.````3P```%8```!7````60```%L`
M``!<````70```%\```!A````8@```&0``````````````&[%WQ_.WD<M:W^:
M?"[%F[;49-1\(?_D#MEQ6!SB1\8!L@&+;ZQ+X\!"^M>'PN4_++KCDGS[H6Q@
M:PE#UF:OS&89?@J'0D75[(D'<--S4)_8,V+;[3[/TFP5C"7,##J7"_]A\F%_
MJ9R;X*<""FL:GE"CX/M)``````````````````````````````````````,`
M#``P'@``````````````````W0(``!$`````````````````````````S0``
M`!(`````````````````````````=@$``!(`````````````````````````
MBP(``!(`````````````````````````=````!(`````````````````````
M````P@```!$`````````````````````````1@$``!(`````````````````
M````````1@(``!(`````````````````````````B@$``!(`````````````
M````````````70$``!(`````````````````````````IP(``!(`````````
M````````````````XP```!(`````````````````````````_`$``!(`````
M````````````````````PP(``!$`````````````````````````XP$``!(`
M````````````````````````I@$``!(`````````````````````````%`$`
M`!(`````````````````````````!`$``!(`````````````````````````
M]@```!(`````````````````````````.P(``!(`````````````````````
M````D0$``!(`````````````````````````)0(``!(`````````````````
M````````RP(``!(``````````````````````````0```"``````````````
M````````````LP$``!(`````````````````````````9`$``!(`````````
M````````````````'0```"``````````````````````````+0(``!(`````
M````````````````````V@$``!(`````````````````````````P@(``"$`
M````````````````````````-P```!(`````````````````````````A`(`
M`!(`````````````````````````P0(``!$`````````````````````````
MTP$``!(`````````````````````````-@$``!(`````````````````````
M````5`(``!(`````````````````````````5````!(`````````````````
M````````L0```!(`````````````````````````90```!(`````````````
M````````````6P(``!(`````````````````````````RP$``!(`````````
M````````````````E0```!(`````````````````````````T@```!(`````
M````````````````````JP$``!(`````````````````````````-`(``!(`
M````````````````````````A`$``!(`````````````````````````*`$`
M`!(`````````````````````````?0$``!(`````````````````````````
M30(``!(`````````````````````````#0(``!$`````````````````````
M````UP```!(`````````````````````````+`(``!(`````````````````
M````````O`$``"(`````````````````````````DP(``!(`````````````
M````````````@````!(`````````````````````````N0(``!(`````````
M````````````````00(``!(`````````````````````````80(``!(`````
M````````````````````40$``!(`````````````````````````:`(``!(`
M````````````````````````I0,``!(`````````````````````````I```
M`!$`````````````````````````F`$``!(`````````````````````````
M'0$``!(`````````````````````````10```!(`````````````````````
M````Z@$``!(`````````````````````````L0(``!(`````````````````
M````````%`(``!(`````````````````````````=@(``!(`````````````
M````````````;P$``!(`````````````````````````K@,``!(`#`!<-@``
M`````-8`````````0`0``!(`#`#8+0```````+(&````````]P$``!(`#``P
M'@```````*X!````````)0,``!(`#`"()@````````(`````````0P,``!(`
M#`"*-````````-(!````````9@0``!(`#`"*)@```````-8!````````)@0`
M`!``%@"(H@``````````````````-@,``!(`#`!@*````````!X`````````
M60,``!(`#`"8+````````&0`````````Q@,``!$`#0!H3`````````0`````
M`````P0``!(`#``$2@```````-@`````````'@0``!(`#`"8)0```````#(`
M````````.P0``!``%@"PL@``````````````````5`0``!(`#``4+0``````
M`,0`````````U0,``!``%```H```````````````````?0,``!(`#`!^*```
M`````,(`````````\0,``!``\?^(J@``````````````````300``!``%0"(
MH@``````````````````<P0``!$`%`!`H`````````@`````````#@0``!``
M%0"(H@``````````````````VP,``!(`#`#@'P```````"(`````````X@,`
M`!``%```H```````````````````,@0``!(`#`"P20```````%0`````````
MUP,``"``%```H```````````````````N@,``!``%@"PL@``````````````
M````DP,``!(`#`#\+````````!@`````````9P,``!(`#`#*)0```````+X`
M````````B0,``!(`#`#<2@```````'X!````````?00``!(`#`!`*0``````
M`%@#`````````%])5$U?9&5R96=I<W1E<E1-0VQO;F5486)L90!?251-7W)E
M9VES=&5R5$U#;&]N951A8FQE`%!E<FQ?<WES7W1E<FT`4&5R;%]S>7-?:6YI
M=#,`4&5R;%]A=&9O<FM?;&]C:P!P97)L7V-O;G-T<G5C=`!097)L7V=E=%]S
M=@!097)L7V-R;V%K7VYO8V]N=&5X=`!097)L7W-V7W-E='!V;@!03%]D;U]U
M;F1U;7``4&5R;%]N97=84U]F;&%G<P!03%]T:')?:V5Y`'!E<FQ?9G)E90!0
M97)L7VUG7W-E=`!097)L7V%T9F]R:U]U;FQO8VL`4&5R;%]S=E]S971P=@!0
M97)L7V=V7V9E=&-H<'8`<&5R;%]R=6X`4&5R;%]N97=84P!P97)L7V1E<W1R
M=6-T`&)O;W1?1'EN84QO861E<@!P97)L7W!A<G-E`%!E<FQ?<V%F97-Y<VUA
M;&QO8P!P97)L7V%L;&]C`&]P96XV-`!S=')T;VL`<W1R9'5P`&UK9&ER`'-T
M<FQE;@!S=')S='(`7U]S<')I;G1F7V-H:P!E>&ET`&UE;6UO=F4`<F5A9&QI
M;FL`7U]C>&%?9FEN86QI>F4`;'-E96LV-`!G971P:60`8VQO<V5D:7(`86-C
M97-S`%]?;&EB8U]S=&%R=%]M86EN`%]?97)R;F]?;&]C871I;VX`<W1D97)R
M`%]?<W1A8VM?8VAK7V9A:6P`=6YL:6YK`&QS=&%T-C0`<W1R8VAR`')M9&ER
M`')E860`9V5T=6ED`&UE;6-H<@!S=')C;7``8VQO<V4`;65M<V5T`%]?9G!R
M:6YT9E]C:&L`7U]S=')N8W!Y7V-H:P!M96UC<'D`<W1R;F-M<`!P=&AR96%D
M7V=E='-P96-I9FEC`')E861D:7(V-`!O<&5N9&ER`')E86QL;V,`7U]E;G9I
M<F]N`%]?<F5G:7-T97)?871F;W)K`%]?<W1A8VM?8VAK7V=U87)D`&QI8G!E
M<FPN<V\N-2XS-`!L:6)C+G-O+C8`;&0M;&EN=7@M<FES8W8V-"UL<#8T9"YS
M;RXQ`'!A<E]C=7)R96YT7V5X96,`<&%R7V)A<V5N86UE`%A37TEN=&5R;F%L
M<U]005)?0D]/5`!P87)?96YV7V-L96%N`'!A<E]C=7)R96YT7V5X96-?<')O
M8P!P87)?9&ER;F%M90!S:&%?9FEN86P`9V5T7W5S97)N86UE7V9R;VU?9V5T
M<'=U:60`<&%R7V-L96%N=7``7U]"4U-?14Y$7U\`7TE/7W-T9&EN7W5S960`
M7U]D871A7W-T87)T`%]?1$%405]"14=)3E]?`%]?9VQO8F%L7W!O:6YT97(D
M`'-H85]U<&1A=&4`7U]31$%405]"14=)3E]?`'AS7VEN:70`7U]B<W-?<W1A
M<G0`<VAA7VEN:70`7V5N9`!P87)?;6MT;7!D:7(`7V5D871A`'!A<E]S971U
M<%]L:6)P871H`'!A<E]F:6YD<')O9P!M>5]P87)?<&P`<&%R7VEN:71?96YV
M`$=,24)#7S(N,S0`1TQ)0D-?,BXS,P!'3$E"0U\R+C(W`````````@`!``,`
M`P`!``$``0`#``,``P`#``$``P`#``,``P`!``$``0`#``,``P`#``$``P`!
M``$`!``#``,``0`#``,``P`!``,``0`!``$``P`#``$``P`#``,``P`!``,`
M`P`#``$`!``#``4``0`#``,``P`!``,``P`!``,``0`!``4``P`#``,``P`!
M``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$`
M`0`!``$``0`!``$````!``,`_P(``!````!`````M)&6!@``!0"*!```$```
M`+.1E@8```0`E00``!````"'D98&```#`*`$`````````0`!``D#```0````
M`````(>1E@8```(`H`0```````#8G0````````,``````````B````````#@
MG0````````,`````````EB````````#HG0````````,`````````7"``````
M````H`````````,``````````*`````````0H`````````,`````````R$T`
M```````8H`````````,``````````%`````````@H`````````,`````````
M"%`````````HH`````````,`````````$%`````````PH`````````,`````
M````&%````````!`H`````````,`````````(%````````"`H@````````,`
M````````,!X````````HH@````````(````"```````````````PH@``````
M``(````'```````````````XH@````````(````-``````````````!`H@``
M``````(````/``````````````!(H@````````(````9``````````````!0
MH@````````(````<``````````````!8H@````````(````D````````````
M``!@H@````````(````F``````````````!HH@````````(````S````````
M``````!PH@````````(````V``````````````!XH@````````(````_````
M``````````!8H`````````4````#``````````````!@H`````````4````$
M``````````````!HH`````````4````%``````````````!PH`````````4`
M```&``````````````!XH`````````4````(``````````````"`H```````
M``4````)``````````````"(H`````````4````*``````````````"0H```
M``````4````+``````````````"8H`````````4````,``````````````"@
MH`````````4````.``````````````"HH`````````4````0````````````
M``"PH`````````4````1``````````````"XH`````````4````2````````
M``````#`H`````````4````3``````````````#(H`````````4````4````
M``````````#0H`````````4````5``````````````#8H`````````4````6
M``````````````#@H`````````4````7``````````````#HH`````````4`
M```8``````````````#PH`````````4````:``````````````#XH```````
M``4````;````````````````H0````````4````=```````````````(H0``
M``````4````>```````````````0H0````````4````@```````````````8
MH0````````4````A```````````````@H0````````4````C````````````
M```HH0````````4````E```````````````PH0````````4````G````````
M```````XH0````````4````H``````````````!`H0````````4````I````
M``````````!(H0````````4````J``````````````!0H0````````4````K
M``````````````!8H0````````4````L``````````````!@H0````````4`
M```M``````````````!HH0````````4````N``````````````!PH0``````
M``4````O``````````````!XH0````````4````P``````````````"`H0``
M``````4````Q``````````````"(H0````````4````R``````````````"0
MH0````````4````T``````````````"8H0````````4````U````````````
M``"@H0````````4````W``````````````"HH0````````4````X````````
M``````"PH0````````4````Y``````````````"XH0````````4````Z````
M``````````#`H0````````4````[``````````````#(H0````````4````\
M``````````````#0H0````````4````]``````````````#8H0````````4`
M```^``````````````#@H0````````4```!```````````````#HH0``````
M``4```!!``````````````#PH0````````4```!"``````````````#XH0``
M``````4```!#````````````````H@````````4```!$```````````````(
MH@````````4```!%```````````````0H@````````4```!&````````````
M```8H@````````4```!'`````````````````````````)>#```S`\-!`[Z#
M7!,#0_V3@H-<$U,3`(.R@@!G``X`%XX```,^CEMG`PX`$P```!>.```#/@Y;
M9P,.`!,````7C@```SZ.6F<##@`3````%XX```,^#EIG`PX`$P```!>.```#
M/HY99P,.`!,````7C@```SX.66<##@`3````%XX```,^CEAG`PX`$P```!>.
M```#/@Y89P,.`!,````7C@```SZ.5V<##@`3````%XX```,^#E=G`PX`$P``
M`!>.```#/HY69P,.`!,````7C@```SX.5F<##@`3````%XX```,^CE5G`PX`
M$P```!>.```#/@Y59P,.`!,````7C@```SZ.5&<##@`3````%XX```,^#E1G
M`PX`$P```!>.```#/HY39P,.`!,````7C@```SX.4V<##@`3````%XX```,^
MCE)G`PX`$P```!>.```#/@Y29P,.`!,````7C@```SZ.46<##@`3````%XX`
M``,^#E%G`PX`$P```!>.```#/HY09P,.`!,````7C@```SX.4&<##@`3````
M%XX```,^CD]G`PX`$P```!>.```#/@Y/9P,.`!,````7C@```SZ.3F<##@`3
M````%XX```,^#DYG`PX`$P```!>.```#/HY-9P,.`!,````7C@```SX.36<#
M#@`3````%XX```,^CDQG`PX`$P```!>.```#/@Y,9P,.`!,````7C@```SZ.
M2V<##@`3````%XX```,^#DMG`PX`$P```!>.```#/HY*9P,.`!,````7C@``
M`SX.2F<##@`3````%XX```,^CDEG`PX`$P```!>.```#/@Y)9P,.`!,````7
MC@```SZ.2&<##@`3````%XX```,^#DAG`PX`$P```!>.```#/HY'9P,.`!,`
M```7C@```SX.1V<##@`3````%XX```,^CD9G`PX`$P```!>.```#/@Y&9P,.
M`!,````7C@```SZ.16<##@`3````%XX```,^#D5G`PX`$P```!>.```#/HY$
M9P,.`!,````7C@```SX.1&<##@`3````%XX```,^CD-G`PX`$P```!>.```#
M/@Y#9P,.`!,````7C@```SZ.0F<##@`3````%XX```,^#D)G`PX`$P```!>.
M```#/HY!9P,.`!,````7C@```SX.06<##@`3````%XX```,^CD!G`PX`$P``
M`!>.```#/@Y`9P,.`!,````7C@```SZ./V<##@`3````'7&JAZ;DEX0``(.T
M)#\NZ#+D#`@P`&@(/LZ<8#[T@4>&[*+HRN!._._PG_<7A@```S;&/;*%%X4`
M``,UI3_O(-!>EX<``(.W9T"#QP<`8XX'#A>$```3!.1`%XD```,Y:3H#)0D`
M[_"_Z0-'I4JJAP,E"0`39R<`(X7G2N_P7^B#1Z5*<D:3YQ<`&P=&`",%]4H3
M%3<`&PDV`._P?^O"9?)'".288:J&&.$7-P``$P=G$1CE%X<```,WQQ48Z1<W
M```3!Z<0&.T%1V-;]PR;B#<`1HBA!1%'B&&3%S<`MI<%)XCCH07CF>C^FP<(
M``ALC@>VETJ&`4>7!0``DX7E8".P!P#O\-^Z*HD]Q0ALDPE!`N_P_]G.A1<U
M```3!07A[P"`%#G-"&SO\)^T[_!?RR)WG&"YCP%'K>OF8$9DIF3B>4J%!FDE
M88*`[_!_QA>$```3!"0Q".PQQ>_P?\T7B0```SDI*@,E"0#O\'_9A6<^E:,+
M!:3UM0AL[_!_NRJ)<;<(:`'%[Q!@:G&_SH47-0``$P4ETN\`(`T(Z$G5Y;>1
M1[&W!47O\+^W[_!_X@``[P`@`JJ'%X4```,UI2F"93``$W$!_X%&`4<*B._P
M7]X"D)>1``"3@6&H@H```!>%```3!:4#EX<``).')P-CB*<`EX<``(.W9R*1
MPX*'@H`7A0``$P6%`9>%``"3A04!B8V3US5`_9&^E86%F<67AP``@[<G()'#
M@H>"@$$1(N`7A```$P2$(H-'!``&Y(7CEX<``(.W!R"1QQ>%```#-67X@I?O
M\+_XA4<C`/0`HF`"9$$!@H!IOSEQ!OPB^";T2O!.[%+H5N1:X$G!EX<``(.W
M1QD#NP<`8PH+!H-'!0"JB2Z**HD3!]`#O<-CAN<`@T<9``4)_?L["3E!`S0+
M`!W`VH23"M`#(H5*ALZ%[_`_G;,')`$)Y8/'!P!C@%<#@&2A!'7PXG`BA4)T
MHG0">>)I0FJB:@)K(6&"@+.$9$&-A`4)(R":`$J4\;\!1.&_`4EMMQ5QRN$7
MB0```SD)#X;MHNFFY4[]4OE6]5KQ7NUBZ8,W"0`^Y8%'"<6#1P4`*H2%YRIG
M@S<)`+F/`4=CG`<,[F!.9*YD#FGJ>4IZJGH*>^IK2FPM88*`[_!_QJJ$<=D7
M.@``$PKJK9,)@0`]:Y%J)H7O\-^7/<F#1C4!DPLU`9N&)OV!YH/&&P#]T@-'
M-0$;!R?]/<,BA>_P?Y,JC%Z%[_#_DCL%K``))>_P7Y/>AR*'TH9]5H5%JHOO
M\%^\SH5>A>_PWY_]5V,(]0#B1[/W9P&!)V.,5P->A>_P7YI>A>_P_Z@FA>_P
MGY!9]2:%[_`?GB*%[_"_EBV_`\<;`!L')_U1^P/'*P`EUW&W7H7O\%_O\;?O
M\+^[<7$F[9>$``"#M*3]+`"<8#[E@4<B\0;U*H3O\-^K#>'B1[UF$6?UCV.%
MYP`I9V.:YP")12*%[_`?C!,U%0`1H`%%*F><8+F/`4>1YZIP"G3J9$UA@H#O
M\!^V77%6[/UWA6K]<N$7$X<*`:+@)OQ*^%+PAN1.]#Z7%I$NBK,%)P`3AXH`
M"I<%9!>)```#.6GU@S<)`!SC@4>JA!,&]/\7-0``$P4%F>_P'XZ;!P4`8UKP
M!!.'"@$*ES,$AT";B??_3I0#1X3_+>]CC0D"?72%9V$4P0>BES.$)P!.AI,%
M\`(BA>_P7YT1S9>'``"#M^?OB$/O\%^?SH8BAJ:%[_"_E"&HEX<``(.W1^Z(
M0^_POYU2AJ:%[_`_@H5GH0>*EYAC@S<)`+F/`4>1[X5B%I&F8`9DXG1">:)Y
M`GKB:F%A@H"^B6FW[_`_IQUQHNBFY,K@4OB&[$[\5O1:\%[L8NB#QP4`%XD`
M``,YR>>JA).'-_R3MQ<`,X3U`"*%@S<)`#[D@4?O\$_S*HI,`":%[_`_S&G-
MJHGO\"_R8WA%"Y)*%XL```,[B^6."@/'!`"FAY,&T`-C!@<28P;7``/'%P"%
M!WW[A9^#.0L`$P4J`#Z5UIGO\&_O(["I`#'%`S<+`(/'!``3A10`5I<48Q,&
MT`,C@/8`@>N-J(-'!0`%!:,`]P"]PS:'A0;CF,?^DP;0`Y,'%P`C`-<``T<$
M`(4'!02CC^?^=?LB9X,W"0"YCP%'S>_F8$9DIF0&:>)Y0GJB>@)[XFM";"5A
M@H"#1P0`A0D%!*./^?[AVX-'!`"%"04$HX_Y_OWSP;<VATVW%XL```,[R]@#
M/`L`@S<,`*7'XH>!29AGSH:A!X4I9?^-)I.5-@"7AP``DX=GVYA#!>L%1RZ%
MF,/O\$_BJHLUW9.:.0!6AN*%[_!/^R,P>P&;AQD`C@>^FR.P"P!.PL6U8H7O
M\+^#(S"K`*J+.=63FCD`^;^!1]6UP46!26VW[_#_C$$1(N`7A````S1DSPA`
M!N3O\*_^"$#O\$_^EV8``).&!G@7A@```S8&T)<E``"3A85R[_"?A0A`[_`O
M_`)DHF`7-P``$P<GIX%'NH87%@``$P:&\)<E``"3A>5Q00%O\,_K01$&Y)>'
M``"#MT?)B$/O\*_XHF"79@``DX9&<A>&```#-D;*ER4``).%Q6Q!`6_PK_]=
M<4KX^7():8;DHN`F_$[T$P>)`1:1"I>7B0``@[EIQ(.W"0`<XX%'[_#OXWET
M(123!PD"HI<SA"<`!68JAY<G``"3AX=KER8``).&AFL%!H5%(H7O\"_Y_73!
M%),'"0*FE[.$)P`BA05FIH7O\*_9&P0%``%)8T\$`!L%%`#O\(_,*HD!R2*&
MIH5*E._PK]PC``0`B6?A!XJ7F&.#MPD`N8\!1YGKB6(6D:9@2H4&9.)T0GFB
M>6%A@H#O\,_WB;=1<=+AA69]>OUR$P=*]Y.'!@FB\:;MRNEB\8;USN56_5KY
M7O5F[;J7%I$3AX8("I<7C````SSLMBJ)+H07)0``$P6E8;.%)P"#-PP`'..!
M1^_P_YNJA),%\`)*A>_PK]TYP1<E```3!45@RH7O\-_)2H6%9Y.'APB*EYAC
M@S<,`+F/`4=CEP<4A6(6D:YP#G3N9$YIKFD.:NIZ2GNJ>PI\ZFQM88*`2H7O
M\.^\JHHBA>_P;]N7)0``DX4E7._PK[:!*BJ$6=V%9Y,)BO\3AP<)3I>S"2<`
M$X<'"9.'!PF*EP5KLXMG08-'!``3"HKW4I>7+```DXSL53,*)P#1SY'$HH4F
MA>_P+\L]R2*%[_"OMIL']?^S!O0``\8&`!,'\`(!)6,>Y@`3!O`"/H7]-R.`
M!@"S!O0``\<&`.,(Q_Z;AQH`J9_CWV?QA45*B)<G``"3AR=3(H>7)@``DX8&
M4P5F3H7O\$_<TH5.A>_PS[\!Z8.GB_B]9B%G]8]CC.<"ER4``).%A4\!1>_P
M[ZDJA.,*!>R#1P0`I?>1Q(/'!`";AR?]@<=FA`5%6;^#QQ0`X=O5OX5%3H7O
M\`^P<?'.A1<E```3!85*[_`_M$Z%[_"OR4VU[_!/V@-'!0"JAQG+DP;P`H4'
M8Q/7`#Z%`\<'`'7[@H""@%W)01$BX`;D@T<%`"J$V<OO\"^G$P;U_R*6$P?P
M`F-FQ`"MH'T68P7$!H-'!@#CB^?^8WW$!!,'\`)]%F,*Q`2#1P8`XYOG_A,'
M\`(IH(-'!@!CE><`?1;C:\3^`8X3!R8`A6<!16/OYP"%9@4&HH47A0``$P4E
MG._PK]$7A0``$P5EFZ)@`F1!`8*`XQ[$^@-'!`"3!_`"%R4``!,%)3]C%O<`
M%R4``!,%93L"9*)@00%O\`^\%R4``!,%13IO\$^[.7$F])>$``"#M$2.(OA*
M\$[L!OR<8#[D@4=``!<I```3"<D[EXD``(.YR8VBA4J%[_"/\A7!$D>#MPD`
M#@>ZEYAGF.-EUYAKH0>8XVW_HH5*A>_P;_!E\1<I```3"0DYEXD``(.Y"8JB
MA4J%[_#/[A7!$D>#MPD`#@>ZEYAGF.-EUYAKH0>8XVW_HH5*A>_PK^QE\1<I
M```3"<DUEXD``(.Y28:BA4J%[_`/ZQ7!$D>#MPD`#@>ZEYAGF.-EUYAKH0>8
MXVW_HH5*A>_P[^AE\1<I```3"0DSEXD``(.YB8*BA4J%[_!/YQ7!$D>#MPD`
M#@>ZEYAGF.-EUYAKH0>8XVW_HH5*A>_P+^5E\1<I```3"<DOEWD``(.YR7ZB
MA4J%[_"/XQ7!$D>#MPD`#@>ZEYAGF.-EUYAKH0>8XVW_HH5*A>_P;^%E\1<I
M```3"0DMEWD``(.Y"7NBA4J%[_#/WQ7!$D>#MPD`#@>ZEYAGF.-EUYAKH0>8
MXVW_HH5*A>_PK]UE\1<I```3"<DAEWD``(.Y27>BA4J%[_`/W!7!$D>#MPD`
M#@>ZEYAGF.-EUYAKH0>8XVW_HH5*A>_P[]EE\1<I```3"8DFEWD``(.YB7.B
MA4J%[_!/V!7!$D>#MPD`#@>ZEYAGF.-EUYAKH0>8XVW_HH5*A>_P+]9E\1<I
M```3"<DCEWD``(.YR6^BA4J%[_"/U!7!$D>#MPD`#@>ZEYAGF.-EUYAKH0>8
MXVW_HH5*A>_P;])E\1<I```3"0DAEWD``(.Y"6RBA4J%[_#/T!7!$D>#MPD`
M#@>ZEYAGF.-EUYAKH0>8XVW_HH5*A>_PK\YE\1<I```3"<D3EWD``(.Y26BB
MA4J%[_`/S17!$D>#MPD`#@>ZEYAGF.-EUYAKH0>8XVW_HH5*A>_P[\IE\:*%
M%R4``!,%91KO\._)JH49Q1<E```3!647[_"/^**%%R4``!,%!1KO\`_(JH49
MQ1<E```3!84:[_"O]J*%%R4``!,%I1KO\"_&JH4%S1<E```3!24*[_#/]")G
MG&"YCP%'J>-"=.)PHG0">>)IER4``).%)1H7)0``$P4E#B%A;_`O\J*%%R4`
M`!,%)1?O\*_!JH5YT1<E```3!24.[_!/\&6_[_#/EGEQ)NR7=```DX3$-B+P
MB$`7=````S0$6!Q@/N2!1P;T_5=C#/4`(F<<8+F/`4>-ZZ)P`G3B9$5A@H!,
M`!<E```3!44)[_#/NZJ'`46!RX/'!P")QY.'!_TS-?``B,#AM^_PCY!!$0;D
M[^`?WP$E[_"OB1'!"&&B8$$!@H`Y<4KP%WD```,Y"5$F]$P`JH2#-PD`/N2!
M1Q<E```3!:4-!OPB^$[L[_#/M17%@T<%`"J$E<.FA>_@7^4IP2)G@S<)`+F/
M`4>E[^)P0G2B=`)YXFDA88*`(F>#-PD`N8\!1Z:%L>]"=.)PHG0">>)I%R4`
M`!,%10@A86_P3^`FA>_@W]:JB2*%[^!?UDZ5"07OX-_6(HB7)P``DX=G]2:'
MA467)@``DX:F]7U6*H3OX/_^(F>#-PD`N8\!1Z*%Q=?O\,^")7$BZTKC(607
M>0``$PF)(N%R)N?._M+Z!N_6]MKRWN[BZN%W%I$#-PD#DP0$%:J)$P4$%1,$
MA!2^E!=Z```#.FI!"I23A<?L`S.)`+.')`"#.`D!`SB)`0,V"0*#-HD"`SX*
M`",PQ`$!3BZ5%RX``!,.3NDCM.?R%R<``!,'!_ZS!24`([S'[1<E```3!07H
M([`'[B.XY^XCO`?N([!G\".T%_$CN`?Q([S'\".PU_+O\`^A$<6#1P4`*H1C
MG`<Z[^"?Q0$E[^`_\&,,!3``86,)!#`BA>_@/\4&!04%[^"_Q0-'!`"JB@W#
MUH07*P``$PO+]R:%VH9]5H5%!03OX+_M`T<$`(D$=?=A>R%GDP0+\),'!Q6F
MEQ,+R^RSA"<`DP<'%=J7%R4``!,%I>PSBR<`*:"(9*$$8P@%#MJ%[_`OF"J$
M9=F#1P4`[=?O\&^R==$BA>_@7]PJA'G%(H7OX+^\JH16A>_@/[RIG)N$1$`F
MA>_@?[S6B)<G``"3AX?;%R@``!,(".\BAY<F``"3AN;N?5:%1:J*[^`?Y),%
M`!Q6A>_@?]7]5V,8]0#OX-^Z'$%%1V.?YRAA>Z%GDP4+\Y.'!Q6NE[.%)P!6
MA>_@W]<JA$7%EW<``(.WQRN#M@D`B&-6AQ<F```3!D;NA47OX+_<@42A9Y.'
MAQ2*EYAC@S<*`+F/`4=CE`=*H6(6D?I@)H5:9+ID&FGV>59ZMGH6>_9K5FP=
M88*`H6=A>Y.'!Q7:EQ<D```3!.3A@40SBR<`$:B3ES0`VI<#M`?M#<2#1P0`
ME<,BA>_PSZ&%)'W1(H7OX)_+*H3C&P7NDY<T`-J7`[0'[6G\`435M:%GDX<'
M%=J7LXLG`(.G"_2]9A%G]8_CDN?T`ZR+]._@'ZB;!P4`XQK\\H.G"_03!P`<
MD_?W'^.2Y_(FA>_@/ZBA9Y,%R^R3AP<5KI>SA2<`JH07)0``$P5%Y>_@W_ZJ
MA6,*!1P#M0D`[_`/W:J+8P,%'%Z%[^"_HQL+!0"-1V/89P,3!<O_ER4``).%
MA>)>E>_@_[4)[9%'8P+[,)L'N__>EP/'!P"3!_`"8PGW+H,G"0!]5V.'YRIC
MA0<8ER4``).%)<\7)0``$P4EQ>_P3Z?OX/^P*HB7*```DX@([)<G``"3AX>]
M5H>7)@``DX9FWGU6A44FA>_@G\9]6<5)%RP``!,,C.F7*P``DXL+NQ<K```3
M"PO=):#OX'^<'$%CES<#[^#?JP4D*HABX**(WH=6A]J&?5:%12:%[^!?PI,%
M`!PFA>_@O[/C""7]5H7OX!^PIH47)0``$P6EL^_P3YXFA>_P'[81O>%Z(6<3
MB\KLDP<'%=J7,XLG`),'!Q76EX%$%R4``!,%1<2SBB<`.:"3ES0`UI<#M8?N
M!<7:A>_@G^J%)'75@T<%`/W3[^`_KRJ$XQ0%RI.7-`#6EP.UA^YQ_35%[^"_
MCZJ*%R0``!,$1,`3!S`%:;D7=P```S?G`PAC@[8)`%:'%R8``!,&9L*%1>_@
MW[2!1$FS[_"?K*%GDX>'%(J7F&.#-PH`N8\!1V.2!R*A8A:1^F"Z9!II]GE6
M>K9Z%GOV:U9L(H5:9!UA;^#_IH.["0`MO9=W```CK@?6@45>A>_@G[@JB^,(
M!>8)1KE5[^"_G6%TH6D3"83_DX<)%<J7,XDG`!E&RH5:A>_@_ZF3APD5HI>*
MEP/'A_\9YP/'E_^3!C`$8P_7$@%&@45:A>_@OYGO$&!L872A9Q,)A/^3AP<5
MRI>JB3.))P`IH,J%3H7O$,!O(6;*A5J%[^#_I!L&!0#C1<#^6H7OX!^5(6L3
M"03[DP<+%<J7,XDG`,Z%2H7O$$!Z$P2$_),'"Q6BES.$)P`3"X0"ERD``).)
M*:\#1PD`(H7.AGU6A44)!._@WZ0%">,6B_ZA9N%W$X<&%1.(A_P^EY.'!A4S
M`R<`PI<SB"<`ER@``).(Z,67)P``DX=GEU:'ER8``).&1K=]5H5%)H4C"`/^
M[^`_H/6SX76A9Y.%Q>R3AP<5KI>SA2<`%R4``!,%)9KOX+_,XPT%ZH-'!0#C
MB0?J$P<``^.%Y^J%1R,@^0`-LX.YB0#CAPG03H7OX(_PC4?C\:?0<167)0``
MDX5%L$Z5[^`_@^,7!<[.B^6Q`\:G_Y,&$`3C'];J@\:W_^.;YNJ#QL?_$P>`
M!..5YNH#Q]?_DP=0!.,?]^@)1I,%8/Q:A>_@/X/*A1,&D`):A>_@?Y"7*```
MDXBHN$J(ER<``).'!XI6AY<F``"3AN:I?5:%12:%[^`?DRF[[^"_EUUQAN2B
MX";\2OA2\$[T5NP7=````S1DV0A`%WD```,Y2=B#-PD`/N2!1^_@WX>JA`A`
M$PI!`._@'X<#QP0+JH?2A1<E```3!<6'HXCG"N_@'[P9Q0-'!0"3!Q`#8P?W
M$N_P;\4(0._@'X2-1@5&ER4``).%!:7OX`_GJH0%Q0A`[^!_@IQH%R8``!,&
M!J2,8^_@;^:<:)QCW$>;UV<!A8MCE`<0"$"7>0``DXD)UN_@C_^-1@5&ER4`
M`).%A:'OX(_BJH0=P=*%%Q4``!,%Y7GOX/^SJHH(0&.."@KOX*_\G&A6AHQC
M[^`/X0A`[^"O^ZJ$"$#OX"_[!4:7)0``DX7%G>_@3]2JA1<F```3!F:>)H7O
MX$_>"$#OX._XHP@%"M*%%Q4``!,%17/OX%^N([BI`"J$#<V3!0`<(H7OX*_P
MQ4=C!_4`FP<5``5'8V;W!B)G@S<)`+F/`4>UZZ9@!F3B=$)YHGD">N)J86&"
M@`.UB0#O\,_]([BI`"J$3?T7)0``$P6%E^_@#_.#1Q4`XXL'[/FU[^`O\0.W
MB0"<:`QCB&/OX)_'D;<(0._@S^^<:(QC[^!/[?VU@[>)`*J&(H:,8Q<E```3
M!<65[^#/[N_@C_HY<2;TEW0``(.TA+R<8#[D@4<B^$[L!OQ*\*J)[_!OH(-'
M!0`JA)'+$P?P`@4%8Y/G`"J$@T<%`/7[%WD``!,)*9>#)PD`?5=CA.<"D<=C
MA0D`@\<)`+'C(F><8+F/`4>MZ^)P0G2B=`)YXFDA88*`3``7%0``$P6E:>_@
M/YPIQ8-'!0"QPQ,'``-CC^<"A4<C(/D`XY\)^L&W$4:7%0``DX4%=2*%[^#O
MNUWU(F><8+F/`4>9[T)TXG"B=`)Y3H7B:2%A;^!?H9=W```CH@>.8;?OX"_M
M$P$!TR,T$2PC,($L(SR1*B,X(2LC-#$K(S!!*R,\42F7>```@[AHK3@`_5]!
M;X.W"``C-/$H@4<3`X4#DP.%!SJ(D]\/`K<"_P`3#P_P`S8#`$$((0.3508"
MDQ:&`1,4A@"35X8"DUZ&`)-4A@,3GH4!L_;V`3-T5`"S]^<!P8ZS_NX!Q8\S
M?OX!H@6SYM8!&U:&`;/GQP&S]54`T8[-CR,XV/XC//C^XY-C^GU6$P,'(`&2
M/'<#.`<$#&L48[/'!P&MC[6/DY87`/V#U8_QCUSC(0?C$&?^@SX%`*)B#&D#
M,X4``SB%`0,^!0(WAX):$P>7F9/7O@$3GUX`,V__`+J2DU\C`+/&!0&3%^,!
M,W_/`/*2L^?W`;/V9@`6G\)BL__'`+/&!@$VG[/&]0$S?\\`L_;6`;J2DQ-?
M`)-4OP&MCL*2EI:SXI,`$]DN`!.4[@&6EN)B,V0D`:&/L_?G`;J2\8ZNDK/'
M]P&3E%8`$]FV`9,3[P&6EQ-?+P""<K/CXP$S[R0!^I<S3W0`NI)QC#-_WP#Q
MCY:?,T^/`).45P`3V;<!DY+F`7Z?B8*B?[/BT@"SYB0!-I^SQE,`,W_/`+/S
MPP#]CKJ?HI^3%%\`$UF_`;/&=@`3E.<!B8-=C/Z6L^<D`;Z6L__&`,)VL\>"
M`+/WYP&S\L(`NI:>EI.47P`3V;\!L\=7`+:7L^8D`;:7DQ/O`1-?+P"SX^,!
M,__'`.)WLT9T`+/V]@%QC+J7EI>3%%\`$UF_`:&.OI:SYR0!OI:3DN\!D]\O
M`+/B\@&S_\8`AF:SQU,`L_?G`;/SPP"ZEJ*6DY1?`!/9OP&SQW<`MI>SYB0!
MMI<3%.\!$U\O`#-DY`$S_\<`IF>SQH(`L_;V`;/RP@"ZEYZ7DQ1?`!-9OP&S
MQE8`OI:SYR0!OI:3D^\!D]\O`+/C\P&S_\8`QF:S1W0`L_?G`7&,NI:6EI.4
M7P`3V;\!H8^VE[/F)`&VEY,2[P$37R\`L^+B`3/_QP#F9[/&4P"S]O8!L_/#
M`+J7HI>3%%\`$UF_`;/&=@"^EK/G)`&^EA.4[P&3WR\`,V3T`;/_Q@"&=K/'
M@@"S]^<!L_+"`+J6GI:3E%\`$]F_`;/'5P"VE[/F)`&VEY,3[P$37R\`L^/C
M`3/_QP"F=[-&=`"S]O8!<8RZEY:7DQ1?`!-9OP&ACKZ6L^<D`;Z6DY+O`9/?
M+P"SXO(!L__&`,9VL\=3`+/WYP&S\\,`NI:BEI.47P`3V;\!L\=W`+:7L^8D
M`;:7$Q3O`1-?+P`S9.0!,__'`.9WL\:"`+/V]@&S\L(`NI>>EY,47P`36;\!
ML\96`+Z6L^<D`;Z6DY/O`9/?+P"SX_,!L__&`(IFLT=T`+/WYP%QC+J6EI:3
ME%\`$]F_`:&/MI>SYB0!MI>3$N\!$U\O`+/BX@$S_\<`JF>SQE,`L_;V`;/S
MPP"ZEZ*7DU2_`1,47P"SQG8`$YGO`;Z6D]\O`+-GE`!*9+-O^0&^EK/'\@'Q
MCK/RP@`ZE+/WYP&BDY/4M@&SQU<`$Y16`$6,GI?J9),3[P$37R\`L^/C`:*7
M\8\SSW\`NI2S_\\`$]FW`3-_WP`3E%<`II(S3_\!,V0D`7&,%I^3DN8!B8(B
MG[/BT@`*>;-TSP"SQE,`_8ZS\\,`$Y14`)/9M`$ZF3/'=@"S9C0!$Y3G`8F#
M78S*G[/'@@#QCGZ7L\?G`2I_LP_7`#?WV6X3!Q>ZL_G/`!/9N0$ZGY.660`>
MG_&/L^8F`?J7\8Z^EI.3Y`'*=XF`L^.3`#/YQ@`S3W0`L_+"`)-4N0&ZE[-/
M_P$3'UD`L__/`):7,V^?`/Z7,W_/`#Z?DY+I`>IWD]DI`+/B,@&S=,\`L\]3
M`'&,D]FT`;J7L\_?`).65`"S_\\`HI>SYC8!_I?QCKZ6DQ_I`8YG$UDI`+/O
M+P$S],8`,\GR`;/YPP"ZE[-#Z0$36;0!$Q]4`+/SPP#.ES-O+P&>ES-_SP`^
MGY.3Y`&N9XF`L^.3`#/)?P"S=,\`L_G"`+J7LT+9`!/9M`&3EE0`L_+"`,Z7
ML^8F`9:7\8Z^EI,2Y`'.9PF`L^*"`#/)4P`S],8`L_G/`+J7LT_I`1-9M`$3
M'U0`L__/`,Z7,V\O`?Z7,W_/`#Z?DY_D`>YGB8"S[Y\`,\GR`;-TSP"S^<,`
MNI>S0]D`$]FT`9.65`"S\\,`SI>SYB8!GI?QCKZ6DQ/D`8YW"8"SXX,`,\E_
M`#/TQ@"S^<(`NI>S0ND!$UFT`1,?5`"S\L(`SI<S;R\!EI<S?\\`/I^3DN0!
MKG>)@+/BD@`SR5,`LW3/`+/YSP"ZE[-/V0`3V;0!DY94`+/_SP#.E[/F)@'^
ME_&.OI:3'^0!SG<)@+/OCP`SR?(!,_3&`+/YPP"ZE[-#Z0$36;0!$Q]4`+/S
MPP#.ES-O+P&>ES-_SP`^GY.3Y`'N=XF`L^.3`#/)?P"S=,\`L_G"`+J7LT+9
M`!/9M`&3EE0`L_+"`,Z7L^8F`9:7\8Z^EI,2Y`&29PF`L^*"`#/)4P`S],8`
ML_G/`+J7LT_I`1-9M`$3'U0`L__/`,Z7,V\O`?Z7,W_/`#Z?DY_D`;)GB8"S
M[Y\`,\GR`;-TSP"S^<,`NI>S0]D`$]FT`9.65`"S\\,`SI>SYB8!GI?QCKZ6
MDQ/D`=)G"8"SXX,`,\E_`#/TQ@"S^<(`NI>S0ND!$UFT`1,?5`"S\L(`SI<S
M;R\!EI<S?\\`/I^3DN0!\F>)@+/BD@`SR5,`LW3/`+/YSP"ZE[-/V0`3V;0!
MDY94`+/_SP#.E[/F)@'^E_&.OI:3'^0!DG<)@+/OCP`S^<8`,\3R`;/YPP"Z
ME[-#Y`$35+D!$Q]9`+/SPP#.ES-OCP">ES-_SP`^GQ.4Y`&R=XF`18RSPX\`
MLW3/`+/YP@"ZE[/"TP"3T[0!DY94`+/RP@#.E[/F=@"6E_&.OI:3$ND!TG<3
M62D`L^(B`;-#5``S^<8`L_G/`+J7L\_C`9-3N0$3'UD`L__/`,Z7,V]_`#-_
MSP#^E[./YP&3D^0!\G>)@+/CDP`SSW(`L_3/`'&,NI<S3]\`,W_/`)/9M`&B
MEQ.45`#ZES-O-`'ZEY,6Z0$6;Q-9*0"SYB8!,\G3`#/TQP"S\L(`LT?Y`3J?
M\8\35[0!%I\3&50`DY_D`8F`L^^?`#-IZ0`^G[/TQ@!*G[/F]@&S\L\`,W_/
M`#?WQB,S]H8`MF;]5PH'@9,3!\?-,_E4`+J6L_/S`+:3DUF_`3-F)@$3&5\`
M$QKD`9-6)``>EC-D.0$BEC-T]@!69K-FV@"S\_8`L^_?`#/Y<@`ZEK/_[P&R
ME)-9M`&S[R\!$QE4`*:?LV0Y`1,6[P&FGQ-?+P#V9#-FY@$S?_8`T8ZS__\`
M,_GC`>&.NI26E)/9OP&SYB8!$YE?`*:6LV0Y`1,:Y`&34B0`II:6=+-B6@`S
M]/(`,V96`/V.,WF/`+J4,W;V`::3,V8F`9.45@`3V;8!L^0D`1Z6DYGO`2:6
MD]\O`+9TL^_Y`;/S_P"SXO(!?8XS>70`L_+2`+J4L^(B`?J4$QE6`)-9M@$3
MG^8!B8(S;]\`LX:2`+-B.0&6EM9RLW3_`+/O[P']CC/YDP"ZDK/_SP"S[R\!
M%I03F58`D]FV`9,2Y@$)@K/BP@`SAH\`LV\Y`7Z6]G\S]/(`,V]?`'V.,_F$
M`+J?,W_?`#-O+P'^DQ,95@"36;8!DY_F`8F"L^_?`+,&?P`S;SD!^I8:;[/S
M_P"SXO(!_8XS>70`.I^S\L(`L^(B`?J4$YE6`)/9M@$3'^8!"8(S;\\`,X:2
M`+-B.0$6EKIBLW3_`+/O[P%]CC/YDP"ZDK/_WP"S[R\!%I03&58`DUFV`9.2
MY@&)@K/BT@"SAH\`LV\Y`?Z6VF\S]/(`,V]?`/V.,_F$`+J?,W_/`#-O+P'^
MDQ.95@"3V;8!DQ_F`0F"L^_/`#,&?P`S;SD!>I9Z;[/S_P"SXO(!?8XS>70`
M.I^S\M(`L^(B`?J4$QE6`)-9M@$3G^8!B8(S;]\`LX:2`+-B.0&6EIIRLW3_
M`+/O[P']CC/YDP"ZDK/_SP"S[R\!%I03F58`D]FV`9,2Y@$)@K/BP@`SAH\`
MLV\Y`7Z6NG\S]/(`,V]?`'V.,_F$`+J?,W_?`#-O+P'^DQ,95@"36;8!DY_F
M`8F"L^_?`+,&?P`S;SD!^I9:?[/S_P"SXO(!_8XS>70`.I^S\L(`L^(B`?J4
M$YE6`)/9M@$3'^8!"8(S;\\`,X:2`+-D.0$FEOITLW+_`+/O[P%]CC/Y4P"S
M_]\`NI2S[R\!HI03&58`DUFV`1.4Y@&)@E6,LX:?`+-D.0$>:;-_]``S;X\`
MII8S?\\`L_3R`3J9_8X>F3-OGP"3F58`$]JV`9-3)@"3%.8!2I\^:;/D=``S
MYDD!L_/T`#*?,V:4`'6.,W3_`#J9,_]_`!:9DQE4`!-:M`$S9N8!D](F`!.?
MY@%*EK/F20$S;U\`-I:SYN0!LW3V`%YFLW+_`#/Y4P#ACCJ6?I:SYB8!DY]4
M`!/9M`&S[R\!LI;^EA,6Y`'^;PF`08XS=/8`,V_/`/V.,_J"`#-_GP"ZGY/9
MM@&>GQ.95@`S;T\!,VDY`7Z?GGF3WR0`DY/D`;/C\P&S__,`,WGY`#-F=@!*
MGW6.LWKT`;J9LW3_`#-G5@$SAED`,I<3F50`$]8F`!/:M`&3DN8!L^+"`#-I
M20&SQE,`,WGY`#J9L\;F`3>WF#(^?PH'$P=G';-Y^0"3T[D!.I\3EED`(I_]
MCC-F=@!]COJ6DY/D`5YTB8`SC\8`L^.3`#/&<@"S=/\`.I0S1B8!DY94`!/9
MM`&BGWV.L^8F`?V.?I8VEA.4Z0'^=I/9*0`S9#0!,WGV`+//@P"S\O(`DUFY
M`;J6L\_O`1,?60"S__\`EI8S;S\!_I8S?_\`-I^3G^0!@S8!((F`L^^?`+-"
M]`&S=/\`L_/S`)/9M`&ZEK/"P@`3EE0`L_+R`)Z6,V8V`9:6?8XVEI,3Z0&#
M-H$@$UDI`+/C(P&SPG\`,WGV`'V,DUFY`;J6L\+B`1,?60"S\O(`HI8S;S\!
MEI8S?_\`-I^3DN0!@S8!(8F`L^*2`#/$4P"S=/\`L_G_`+J6LT_$`!/4M`$3
MEE0`L___`,Z608[^EGV.-I:3'^D!@S:!(1-9*0"S[R\!,W3V`#/)\@&S^?,`
MNI:S0^D!$UFT`1,?5`"S\_,`SI8S;R\!GI8S?_\`-I^3D^0!@S8!(HF`L^.3
M`#/)?P"S=/\`L_GR`+J6LT+)`!/9M`$3EE0`L_+R`,Z6,V8F`9:6?8XVEI,2
MY`&#-H$B"8"SXH(`,\E3`#-T]@"S^?\`NI:S3^D!$UFT`1,?5`"S__\`SI8S
M;R\!_I8S?_\`-I^3G^0!@S8!(XF`L^^?`#/)\@&S=/\`L_GS`+J6LT/)`!/9
MM`$3EE0`L_/S`,Z6,V8F`9Z6?8XVEI,3Y`&#-H$C"8"SXX,`,\E_`#-T]@"S
M^?(`NI:S0ND!$UFT`1,?5`"S\O(`SI8S;R\!EI8S?_\`-I^3DN0!@S8!)(F`
ML^*2`#/)4P"S=/\`L_G_`+J6LT_)`!/9M`$3EE0`L___`,Z6,V8F`?Z6?8XV
MEI,?Y`&#-H$D"8"S[X\`,\GR`3-T]@"S^?,`NI:S0^D!$UFT`1,?5`"S\_,`
MSI8S;R\!GI8S?_\`-I^3D^0!@S8!)8F`L^.3`#/)?P"S=/\`L_GR`+J6LT+)
M`!/9M`$3EE0`L_+R`,Z6,V8F`9:6?8XVEI,2Y`&#-H$E"8"SXH(`,\E3`#-T
M]@"S^?\`NI:S3^D!$UFT`1,?5`"S__\`SI8S;R\!_I8S?_\`-I^3G^0!@S8!
M)HF`L^^?`#-Y_P"SQ/(!L_GS`+J6L\/$`)-4N0$3%ED`L_/S`,Z618Z>EGV.
M-I:3%.0!@S:!)@F`P8RSPY\`,W3V`+/Y\@"ZEK/"XP&34[0!$Q]4`+/R\@#.
MEC-O?P`S?_\`EI:S@N8!DQ/I`8,V`2<362D`L^,C`3//=``S^?(`L___`#-/
MSP"36;D!NI83%ED`_I8S9C8!LW__`'V._I:SC\8`$Q_D`0,V@2<)@#-OCP"S
MQN,!,_3_`/V,.I:SQE8`_8XFEI-9M`&3%%0`-I:SYC0!-I:#-@$HDQ+I`1-9
M*0"SXB(!NI:S1%\`,W?V`/:6L_/S`#/&]`%]CI,>5P"37[<!GI:REC/F_@&3
M'N0!"8"REK/NC@#]CCJ3,P;/`3.'O@"SA0(!?8\4X?V-LW;S`/&/&.D<\13E
M#.T#-X$H@[<(`+F/`4>5XX,P@2P#-`$L@S2!*P,Y`2N#.8$J`SH!*H,Z@2D3
M`0$M@H#OT$_%01$3!0`(!N3OT(^5MW9=3(8&DX;FSS=WZ6$W)D5G%.D3!A8P
MMU8R$`8'$.&3AF9'%T8```,V!C`3!P<?$.44[1CQ(S0%`B,X!0(C+`4&HF!!
M`8*`.7$B^";T2O!2Z`;\3NQ6Y!AUDQ<V`!1YNI>"%X&3,[?G`*J$NI8H71-7
MU@$VEYSTF/@RB2Z$$XJ$`S'MDP?P`V/:)PD;"0G\FUII`)N)&@":":*9HH43
M!@`$4H7OT`^<$P0$!":%[^"?S.,5-/^;FFH`.PE904J&SH52A>_0#YHCK"0'
MXG!"=*)T`GGB:4)JHFHA88*`DPD`!+N'J4"^B6-(]@*;B@D`5H:BA5*5[]#O
MEKQ<$P<`!+N&^0"TW..3YOPFA3L).4%6E._@7\:]M[*)R;^BB46W.7$B^";T
M2O!.[%K@!OQ2Z%;D`[J%`H/7A0(#UP4#$U8Z`!-V]@,;F(<`FQ:'`!.+A0.A
M@R&#+H2SYP<!LP7+`%6/$P@`^),&%@"#.@0#$YD'`R.`!0&3&0<#DP6``ZJ$
M$UD)`Y/9"0,%)C,%VP!CT-40DP<`!#N&QT"!1>_0CZ$BA>_@7[T3!H`#@45:
MA>_0;Z"35XH!$]>*`1-:"@&3V@H!(H6C"%0'(QDT!R,*]`:C"D0'(QLD!R,(
MY`;OX+^Y'&`BA>&#(X#T`!Q@P8.C@/0`'&"A@R.!]``<8*.!]``<9.&#(X+T
M`!QDP8.C@O0`'&2A@R.#]``<9*.#]``<:.&#(X3T`!QHP8.CA/0`'&BA@R.%
M]``<:*.%]``<;.&#(X;T`!QLP8.CAO0`'&RA@R.']``<;*.']``<<.&#(XCT
M`!QPP8.CB/0`''"A@R.)]``<<*.)]`!"=.)PHG0">>)I0FJB:@)K(6%OT*^%
MDP>``SN&QT"!1>_0SY$9OY=6``"#MF8Z;\#_]0```0`"```````E<R\E<P``
M`"]P<F]C+W-E;&8O97AE``!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D97(`
M`````$EN=&5R;F%L<SHZ4$%2.CI"3T]4`````&5X90``````+W!R;V,O)6DO
M)7,``````"X`````````4$%27U1%35```````````%!!4E]04D]'3D%-10``
M```Z`````````"\`````````)7,E<R5S``!015),-4Q)0@``````````4$52
M3$Q)0@!015),-4]05```````````4$523$E/``!005)?24Y)5$E!3$E:140`
M4$%27U-005=.140``````%!!4E]#3$5!3@````````!005)?1$5"54<`````
M````4$%27T-!0TA%`````````%!!4E]'3$]"04Q?1$5"54<``````````%!!
M4E]'3$]"04Q?5$U01$E2`````````%!!4E]435!$25(```````!005)?1TQ/
M0D%,7U1%35``4$%27T=,3T)!3%]#3$5!3@``````````,0````````!,1%],
M24)205)97U!!5$@`55-%4@````!365-414T``"]T;7``````55-%4DY!344`
M`````````"4P,G@`````<&%R+0`````E<R5S)7,E<P``````````)7,Z(&-R
M96%T:6]N(&]F('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R
M;F\])6DI"@```````"5S.B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!I<R!U
M;G-A9F4@*'!L96%S92!R96UO=F4@:70@86YD(')E=')Y('EO=7(@;W!E<F%T
M:6]N*0H```````!0051(`````'!A<FP`````+G!A<@`````E<R5S8V%C:&4M
M)7,E<P``)7,E<W1E;7`M)74E<P```"5S)7-T96UP+25U+25U)7,`````````
M`!@`````````<&5R;``````P`````````%!!4CHZ4&%C:V5R.CI615)324].
M`````#$N,#4U````56YA8FQE('1O(&-R96%T92!C86-H92!D:7)E8W1O<GD`
M`````````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E(&-A8VAE('-U8F1I<F5C
M=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H``````````"UE````````+2T`
M``````!435!$25(``%1%35!$25(`5$5-4`````!435```````&5V86P@)V5X
M96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")])PII9B`P.R`C(&YO
M="!R=6YN:6YG('5N9&5R('-O;64@<VAE;&P*<&%C:V%G92!?7W!A<E]P;#L*
M;7D@*"1005)?34%'24,L("1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL
M92P@)4UO9'5L94-A8VAE*3L*14Y$('L@:68@*"1%3E9[4$%27T-,14%.?2D@
M>PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ0F%S96YA;64[
M"G)E<75I<F4@1FEL93HZ4W!E8SL*;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N
M86UE.CID:7)N86UE*"1P87)?=&5M<"D["F]U=',H<7%;4F5M;W9I;F<@9FEL
M97,@:6X@(B1P87)?=&5M<")=*3L*1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U
M8B![("@@+60@*2`_(')M9&ER(#H@=6YL:6YK('TL("1P87)?=&5M<"D["G)M
M9&ER("1P87)?=&5M<#L*:68@*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@)TU3
M5VEN,S(G*2!["FUY("1T;7`@/2!N97<@1FEL93HZ5&5M<"@*5$5-4$Q!5$4@
M/3X@)W1M<%A86%A8)RP*1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N86UE
M*"1T;W!D:7(I+`I3549&25@@/3X@)RYC;60G+`I53DQ)3DL@/3X@,"P**3L*
M;7D@)&9I;&5N86UE(#T@)'1M<"T^9FEL96YA;64["G!R:6YT("1T;7`@/#PB
M+BXN(CL*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F("<D
M<&%R7W1E;7`G"FEF(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@IB<F5A
M:PIF:0IS;&5E<"`Q"G@]8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G)&9I;&5N
M86UE)PHN+BX*8VQO<V4@)'1M<#L*8VAM;V0@,#<P,"P@)&9I;&5N86UE.PIM
M>2`D8VUD(#T@(B1F:6QE;F%M92`^+V1E=B]N=6QL(#(^)C$@)B(["G-Y<W1E
M;2@D8VUD*3L*;W5T<RAQ<5M3<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T
M;R!P97)F;W)M(&-L96%N=7`Z("1F:6QE;F%M95TI.PI]"GT@?0I"14=)3B![
M"B1005)?34%'24,@/2`B7&Y005(N<&U<;B(["DEN=&5R;F%L<SHZ4$%2.CI"
M3T]4*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0["F5V86P@
M>PI?<&%R7VEN:71?96YV*"D["FUY("1Q=6EE="`]("$D14Y6>U!!4E]$14)5
M1WT["FUY("5S>7,@/2`H"G!A=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I
M;B\@/R`G.R<@.B`G.B<I+`I?97AE("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z
M35-7:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`I?9&5L:6T@("`@
M("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI.PI?
M<V5T7W!R;V=N86UE*"D["F]U=',H<7%;7"1P<F]G;F%M92`]("(D<')O9VYA
M;64B72D["E]S971?<&%R7W1E;7`H*3L*;W5T<RAQ<5M<)$5.5GM005)?5$5-
M4'T@/2`B)$5.5GM005)?5$5-4'TB72D["FUY("@D<W1A<G1?<&]S+"`D9&%T
M85]P;W,I.PI-04=)0SH@>PIL;V-A;"`D4TE'>U]?5T%23E]??2`]('-U8B![
M?3L*=6YL97-S("AO<&5N(%]&2"P@)SPZ<F%W)RP@)'!R;V=N86UE*2!["F]U
M=',H<7%;0V%N)W0@<F5A9"!F<F]M(&9I;&4@(B1P<F]G;F%M92)=*3L@(",@
M9&]N)W0@=7-E("0A(&AE<F4@87,@:70@<F5Q=6ER97,@17)R;F\N<&T*;&%S
M="!-04=)0SL*?0IM>2`D8VAU;FM?<VEZ92`](#8T("H@,3`R-#L*;7D@)&)U
M9CL*;7D@)'-I>F4@/2`M<R!?1D@["FUY("1M86=I8U]P;W,@/2`D<VEZ92`M
M("1S:7IE("4@)&-H=6YK7W-I>F4[(",@3D]413H@)&UA9VEC7W!O<R!I<R!A
M(&UU;'1I<&QE(&]F("1C:'5N:U]S:7IE"G=H:6QE("@D;6%G:6-?<&]S(#X]
M(#`I('L*<V5E:R!?1D@L("1M86=I8U]P;W,L(#`["G)E860@7T9(+"`D8G5F
M+"`D8VAU;FM?<VEZ92`K(&QE;F=T:"@D4$%27TU!1TE#*3L*:68@*"AM>2`D
M:2`](')I;F1E>"@D8G5F+"`D4$%27TU!1TE#*2D@/CT@,"D@>PHD;6%G:6-?
M<&]S("L]("1I.PIL87-T.PI]"B1M86=I8U]P;W,@+3T@)&-H=6YK7W-I>F4[
M"GT*:68@*"1M86=I8U]P;W,@/"`P*2!["F]U=',H<7%;0V%N)W0@9FEN9"!M
M86=I8R!S=')I;F<@(B1005)?34%'24,B(&EN(&9I;&4@(B1P<F]G;F%M92)=
M*3L*;&%S="!-04=)0SL*?0IO=71S*")&;W5N9"!005(@;6%G:6,@870@<&]S
M:71I;VX@)&UA9VEC7W!O<R(I.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M(#0L
M(#`["G)E860@7T9(+"`D8G5F+"`T.PIM>2`D;V9F<V5T(#T@=6YP86-K*").
M(BP@)&)U9BD["F]U=',H(D]F9G-E="!F<F]M('-T87)T(&]F($9)3$5S(&ES
M("1O9F9S970B*3L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`T("T@)&]F9G-E
M="P@,#L*)&1A=&%?<&]S(#T@=&5L;"!?1D@["FUY("5R97%U:7)E7VQI<W0[
M"G)E860@7T9(+"`D8G5F+"`T.R`@("`@("`@("`@("`@("`@("`@("`@("`@
M(",@<F5A9"!T:&4@9FER<W0@(D9)3$4B"G=H:6QE("@D8G5F(&5Q(")&24Q%
M(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C
M:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO=71S*'%Q6U5N
M<&%C:VEN9R!&24Q%("(D9G5L;&YA;64B+BXN72D["FUY("1C<F,@/2`H("1F
M=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD968[
M"FUY("@D8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I/R@N
M*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F
M+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@*&1E9FEN960H)&5X="D@86YD("1E
M>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["FUY("1F:6QE;F%M92`]
M(%]S879E7V%S*"(D8W)C)&5X="(L("1B=68L(#`W-34I.PHD4$%2.CI(96%V
M>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B1005(Z.DAE
M879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*?0IE;'-I
M9B`H("1F=6QL;F%M92`]?B!M?%XO/W-H;&EB+WP@86YD(&1E9FEN960@)$5.
M5GM005)?5$5-4'T@*2!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D8F%S
M96YA;64D97AT(BP@)&)U9BP@,#<U-2D["F]U=',H(E-(3$E".B`D9FEL96YA
M;65<;B(I.PI]"F5L<V4@>PHD36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*
M8G5F(#T^("1B=68L"F-R8R`]/B`D8W)C+`IN86UE(#T^("1F=6QL;F%M92P*
M?3L*)')E<75I<F5?;&ES='LD9G5L;&YA;65]*RL["GT*<F5A9"!?1D@L("1B
M=68L(#0["GT*;&]C86P@0$E.0R`]("AS=6(@>PIM>2`H)'-E;&8L("1M;V1U
M;&4I(#T@0%\["G)E='5R;B!I9B!R968@)&UO9'5L92!O<B`A)&UO9'5L93L*
M;7D@)&EN9F\@/2`D36]D=6QE0V%C:&5[)&UO9'5L97T["G)E='5R;B!U;FQE
M<W,@)&EN9F\["F1E;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5].PHD24Y#
M>R1M;V1U;&5](#T@(B]L;V%D97(O)&EN9F\O)&UO9'5L92(["FEF("@D14Y6
M>U!!4E]#3$5!3GT@86YD(&1E9FEN960H)DE/.CI&:6QE.CIN97<I*2!["FUY
M("1F:"`]($E/.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D:64@(D-A;B=T(&-R
M96%T92!T96UP(&9I;&4Z("0A(CL*)&9H+3YB:6YM;V1E*"D["B1F:"T^<')I
M;G0H)&EN9F\M/GMB=69]*3L*)&9H+3YS965K*#`L(#`I.PIR971U<FX@)&9H
M.PI]"F5L<V4@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B)&EN9F\M/GMC
M<F-]+G!M(BP@)&EN9F\M/GMB=69]*3L*)&EN9F\M/GMF:6QE?2`]("1F:6QE
M;F%M93L*;W!E;B!M>2`D9F@L("<\.G)A=R<L("1F:6QE;F%M92!O<B!D:64@
M<7%;0V%N)W0@<F5A9"`B)&9I;&5N86UE(CH@)"%=.PIR971U<FX@)&9H.PI]
M"F1I92`B0F]O='-T<F%P<&EN9R!F86EL960Z(&-A;B=T(&9I;F0@;6]D=6QE
M("1M;V1U;&4A(CL*?2P@0$E.0RD["G)E<75I<F4@6%-,;V%D97(["G)E<75I
M<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%
M>'!O<G1E<CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H
M*3L*<F5Q=6ER92!)3SHZ1FEL93L*=VAI;&4@*&UY("1F:6QE;F%M92`]("AS
M;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI('L*=6YL97-S("@D24Y#>R1F
M:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^("]"4T1004XO*2!["FEF("@D9FEL
M96YA;64@/7X@+UPN<&UC/R0O:2D@>PIR97%U:7)E("1F:6QE;F%M93L*?0IE
M;'-E('L*9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL96YA;64@/7X@+W-I=&5C
M=7-T;VUI>F5<+G!L)"\["GT*?0ID96QE=&4@)')E<75I<F5?;&ES='LD9FEL
M96YA;65].PI]"G5N;&5S<R`H)&)U9B!E<2`B4$M<,#`S7#`P-"(I('L*;W5T
M<RAQ<5M.;R!Z:7`@9F]U;F0@869T97(@1DE,12!S96-T:6]N(&EN(&9I;&4@
M(B1P<F]G;F%M92)=*3L*;&%S="!-04=)0R`["GT*)'-T87)T7W!O<R`]("AT
M96QL(%]&2"D@+2`T.R`@("`@("`@("`@("`@("`C('-T87)T(&]F('II<`I]
M"FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A
M8VAE7VYA;64I.PID96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S86YI
M=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*)'%U:65T
M(#T@,"!U;FQE<W,@)$5.5GM005)?1$5"54=].PII9B`H(21S=&%R=%]P;W,@
M;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*
M;7D@)61I<W1?8VUD(#T@<7<H"G`@("!B;&EB7W1O7W!A<@II("`@:6YS=&%L
M;%]P87(*=2`@('5N:6YS=&%L;%]P87(*<R`@('-I9VY?<&%R"G8@("!V97)I
M9GE?<&%R"BD["FEF("A`05)'5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G
M*2!["G-H:69T($!!4D=6.PHD14Y6>U!!4E]!4%!?4D554T5](#T@<VAI9G0@
M0$%21U8["GT*96QS92![(",@;F]R;6%L('!A<FP@8F5H879I;W5R"FUY($!A
M9&1?=&]?:6YC.PIW:&EL92`H0$%21U8I('L*)$%21U9;,%T@/7X@+UXM*%M!
M24U/0DQB<7!I=7-4=ETI*"XJ*2\@;W(@;&%S=#L*:68@*"0Q(&5Q("=))RD@
M>PIP=7-H($!A9&1?=&]?:6YC+"`D,CL*?0IE;'-I9B`H)#$@97$@)TTG*2![
M"F5V86P@(G5S92`D,B(["GT*96QS:68@*"0Q(&5Q("=!)RD@>PIU;G-H:69T
M($!P87)?87)G<RP@)#(["GT*96QS:68@*"0Q(&5Q("=/)RD@>PHD;W5T(#T@
M)#(["GT*96QS:68@*"0Q(&5Q("=B)RD@>PHD8G5N9&QE(#T@)W-I=&4G.PI]
M"F5L<VEF("@D,2!E<2`G0B<I('L*)&)U;F1L92`]("=A;&PG.PI]"F5L<VEF
M("@D,2!E<2`G<2<I('L*)'%U:65T(#T@,3L*?0IE;'-I9B`H)#$@97$@)TPG
M*2!["F]P96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@<7%;0V%N)W0@;W!E
M;B!L;V<@9FEL92`B)#(B.B`D(5T["GT*96QS:68@*"0Q(&5Q("=4)RD@>PHD
M8V%C:&5?;F%M92`]("0R.PI]"G-H:69T*$!!4D=6*3L*:68@*&UY("1C;60@
M/2`D9&ES=%]C;61[)#%]*2!["F1E;&5T92`D14Y6>R=005)?5$5-4"=].PII
M;FET7VEN8R@I.PIR97%U:7)E(%!!4CHZ1&ES=#L*)GLB4$%2.CI$:7-T.CHD
M8VUD(GTH*2!U;FQE<W,@0$%21U8["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?
M*2!F;W(@0$%21U8["F5X:70["GT*?0IU;G-H:69T($!)3D,L($!A9&1?=&]?
M:6YC.PI]"GT*:68@*"1O=70I('L*>PIR97%U:7)E($E/.CI&:6QE.PIR97%U
M:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*?0IM>2`D
M<&%R(#T@<VAI9G0H0$%21U8I.PIM>2`D>FEP.PII9B`H9&5F:6YE9"`D<&%R
M*2!["F]P96X@;7D@)&9H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG
M="!F:6YD('!A<B!F:6QE("(D<&%R(CH@)"%=.PIB;&5S<R@D9F@L("=)3SHZ
M1FEL92<I.PHD>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II<"T^<F5A
M9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!
M6E]/2R@I("D*;W(@9&EE('%Q6T5R<F]R(')E861I;F<@>FEP(&%R8VAI=F4@
M(B1P87(B73L*?0II9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)'!H+"`G
M/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG="!R96%D('!A<B!F:6QE("(D
M<&%R(CH@)"%=.PIM>2`D8G5F.PIR96%D("1P:"P@)&)U9BP@-#L*9&EE('%Q
M6R(D<&%R(B!I<R!N;W0@82!P87(@9FEL95T@=6YL97-S("1B=68@97$@(E!+
M7#`P,UPP,#0B.PIC;&]S92`D<&@["GT*0W)E871E4&%T:"@D;W5T*2`["FUY
M("1F:"`]($E/.CI&:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE.CI/7T-214%4
M*"D@?"!)3SHZ1FEL93HZ3U]74D].3%DH*2!\($E/.CI&:6QE.CI/7U1254Y#
M*"DL"C`W-S<L"BD@;W(@9&EE('%Q6T-A;B=T(&-R96%T92!F:6QE("(D;W5T
M(CH@)"%=.PHD9F@M/F)I;FUO9&4H*3L*<V5E:R!?1D@L(#`L(#`["FUY("1L
M;V%D97(["FEF("AD969I;F5D("1D871A7W!O<RD@>PIR96%D(%]&2"P@)&QO
M861E<BP@)&1A=&%?<&]S.PI](&5L<V4@>PIL;V-A;"`D+R`]('5N9&5F.PHD
M;&]A9&5R(#T@/%]&2#X["GT*:68@*"$D14Y6>U!!4E]615)"051)37T@86YD
M("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["G)E<75I<F4@4$%2.CI&
M:6QT97(Z.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P<&QY
M*%PD;&]A9&5R+"`D,"D["GT*)&9H+3YP<FEN="@D;&]A9&5R*0IO<B!D:64@
M<7%;17)R;W(@=W)I=&EN9R!L;V%D97(@=&\@(B1O=70B.B`D(5T["FEF("@D
M8G5N9&QE*2!["G)E<75I<F4@4$%2.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN
M:71?9'EN86QO861E<B@I.PII;FET7VEN8R@I.PIR97%U:7)E7VUO9'5L97,H
M*3L*;7D@0&EN8R`](&=R97`@>R`A+T)31%!!3B\@?0IG<F5P('L**"1B=6YD
M;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL
M:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI
M.PI]($!)3D,["G-\+RM\+WQG+"!S?"\D?'P@9F]R96%C:"!`:6YC.PIM>2`E
M9FEL97,["B1F:6QE<WLD7WTK*R!F;W(@0$1Y;F%,;V%D97(Z.F1L7W-H87)E
M9%]O8FIE8W1S+"!V86QU97,@)4E.0SL*;7D@)&QI8E]E>'0@/2`D0V]N9FEG
M.CI#;VYF:6=[;&EB7V5X='T[("`@("`@("`@(R!86%@@;&EB7V5X="!V<R!D
M;&5X="`_"FUY("5W<FET=&5N.PIF;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y
M<R`E9FEL97,I('L*;7D@*"1F:6QE+"`D;F%M92D["FEF("AD969I;F5D*&UY
M("1F8R`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&ME>7TI*2!["B@D9FEL
M92P@)&YA;64I(#T@*"1K97DL("1F8RD["GT*96QS92!["F9O<F5A8V@@;7D@
M)&1I<B`H0&EN8RD@>PII9B`H)&ME>2`]?B!M?%Y<421D:7)<12\H+BHI)'QI
M*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL("0Q*3L*;&%S=#L*?0II9B`H
M)&ME>2`]?B!M?%XO;&]A9&5R+UM>+UTK+R@N*BDD?"D@>PII9B`H;7D@)')E
M9B`]("1-;V1U;&5#86-H97LD,7TI('L**"1F:6QE+"`D;F%M92D@/2`H)')E
M9BP@)#$I.PIL87-T.PI]"FEF("@M9B`B)&1I<B\D,2(I('L**"1F:6QE+"`D
M;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0["GT*?0I]"GT*;F5X="!U
M;FQE<W,@9&5F:6YE9"`D;F%M93L*;F5X="!I9B`D=W)I='1E;GLD;F%M97TK
M*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB
M7V5X=%Q%)"]I.PIO=71S*'-P<FEN=&8H<7%;4&%C:VEN9R!&24Q%("(E<R(N
M+BY=+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65](#H@)&9I;&4I*3L*;7D@
M)&-O;G1E;G0["FEF("AR968H)&9I;&4I*2!["B1C;VYT96YT(#T@)&9I;&4M
M/GMB=69].PI]"F5L<V4@>PIL;V-A;"`D+R`]('5N9&5F.PIO<&5N(&UY("1T
M:"P@)SPZ<F%W)RP@)&9I;&4@;W(@9&EE('%Q6T-A;B=T(')E860@(B1F:6QE
M(CH@)"%=.PHD8V]N=&5N="`](#PD=&@^.PIC;&]S92`D=&@["E!!4CHZ1FEL
M=&5R.CI0;V13=')I<"T^87!P;'DH7"1C;VYT96YT+"`B/&5M8F5D9&5D/B\D
M;F%M92(I"FEF("$D14Y6>U!!4E]615)"051)37T@86YD("1N86UE(#U^("]<
M+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N="T^
M;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M92D["GT*)&9H+3YP
M<FEN="@B1DE,12(L"G!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@.2DL"G-P
M<FEN=&8H(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D
M8V]N=&5N="DL("1N86UE*2P*<&%C:R@G3B<L(&QE;F=T:"@D8V]N=&5N="DI
M+`HD8V]N=&5N="D*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@96UB961D960@
M1DE,12!T;R`B)&]U="(Z("0A73L*;W5T<RAQ<5M7<FET=&5N(&%S("(D;F%M
M92)=*3L*?0I]"FEF("@D>FEP*2!["B1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE
M*"1F:"D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2PIO<B!D:64@<7%;17)R;W(@
M=W)I=&EN9R!Z:7`@<&%R="!O9B`B)&]U=")=.PI]"B1C86-H95]N86UE(#T@
M<W5B<W1R("1C86-H95]N86UE+"`P+"`T,#L*:68@*"$D8V%C:&5?;F%M92!A
M;F0@;7D@)&UT:6UE(#T@*'-T870H)&]U="DI6SE=*2!["FUY("1C='@@/2!$
M:6=E<W0Z.E-(02T^;F5W*#$I.PIO<&5N(&UY("1T:"P@(CPZ<F%W(BP@)&]U
M=#L*)&-T>"T^861D9FEL92@D=&@I.PIC;&]S92`D=&@["B1C86-H95]N86UE
M(#T@)&-T>"T^:&5X9&EG97-T.PI]"B1C86-H95]N86UE("X](")<,"(@>"`H
M-#`@+2!L96YG=&@@)&-A8VAE7VYA;64I.PHD8V%C:&5?;F%M92`N/2`B7#!#
M04-(12(["FUY("1O9F9S970@/2`D9F@M/G1E;&P@*R!L96YG=&@H)&-A8VAE
M7VYA;64I("T@;&5N9W1H*"1L;V%D97(I.PHD9F@M/G!R:6YT*"1C86-H95]N
M86UE+`IP86-K*"=.)RP@)&]F9G-E="DL"B1005)?34%'24,I"B8F("1F:"T^
M8VQO<V4*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@=')A:6QE<B!O9B`B)&]U
M="(Z("0A73L*8VAM;V0@,#<U-2P@)&]U=#L*97AI=#L*?0I["FQA<W0@=6YL
M97-S(&1E9FEN960@)'-T87)T7W!O<SL*7V9I>%]P<F]G;F%M92@I.PIR97%U
M:7)E(%!!4CL*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PI["G)E
M<75I<F4@1FEL93HZ1FEN9#L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*;7D@
M)&9H(#T@24\Z.D9I;&4M/FYE=SL@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(",@07)C:&EV93HZ6FEP(&]P97)A=&5S(&]N(&%N($E/.CI(86YD;&4*
M)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE('%Q6V9D;W!E
M;B@I(&9A:6QE9#H@)"%=.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@M
M<R!?1D@I.PIM>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@D>FEP+3YR
M96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z
M.EII<#HZ05I?3TLH*2D*;W(@9&EE('%Q6T5R<F]R(')E861I;F<@>FEP(&%R
M8VAI=F4@(B1P<F]G;F%M92)=.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ
M92@V-"`J(#$P,C0I.PHD<75I970@/2`A)$5.5GM005)?1$5"54=].PIO=71S
M*")296%D:6YG($U%5$$N>6UL+BXN(BD["FEF("AM>2`D;65T82`]("1Z:7`M
M/F-O;G1E;G1S*"=-151!+GEM;"<I*2!["B1M971A(#U^(',O+BI><&%R.EQS
M*B0O+VUS.PHD;65T82`]?B!S+UY<4RXJ+R]M<SL*:68@*&UY("@D8VQE86XI
M(#T@)&UE=&$@/7X@+UY<<RMC;&5A;CH@*"XJ*20O;2D@>PHD8VQE86X@/7X@
M+UY<<RI\7',J)"]G.PHD14Y6>U!!4E]#3$5!3GT@/2`Q(&EF("1C;&5A;CL*
M?0I]"G!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B1005(Z.DQI8D-A8VAE
M>R1P<F]G;F%M97T@/2`D>FEP.PIO=71S*")%>'1R86-T:6YG('II<"XN+B(I
M.PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2D@>R`C('-H;W5L9"!B92!S
M970@870@=&AI<R!P;VEN="$*9F]R96%C:"!M>2`D;65M8F5R("@@)'II<"T^
M;65M8F5R<R`I('L*;F5X="!I9B`D;65M8F5R+3YI<T1I<F5C=&]R>3L*;7D@
M)&UE;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA;64["FYE>'0@=6YL97-S
M("1M96UB97)?;F%M92`]?B!M>PI>"B\_<VAL:6(O"B@_.B1#;VYF:6<Z.D-O
M;F9I9WMV97)S:6]N?2\I/PHH/SHD0V]N9FEG.CI#;VYF:6=[87)C:&YA;65]
M+RD_"BA;7B]=*RD*)`I]>#L*;7D@)&5X=')A8W1?;F%M92`]("0Q.PIM>2`D
M9&5S=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T9FEL92@D14Y6>U!!4E]414U0
M?2P@)&5X=')A8W1?;F%M92D["FEF("@M9B`D9&5S=%]N86UE("8F("US(%\@
M/3T@)&UE;6)E<BT^=6YC;VUP<F5S<V5D4VEZ92@I*2!["F]U=',H<7%;4VMI
M<'!I;F<@(B1M96UB97)?;F%M92(@<VEN8V4@:70@86QR96%D>2!E>&ES=',@
M870@(B1D97-T7VYA;64B72D["GT@96QS92!["F]U=',H<7%;17AT<F%C=&EN
M9R`B)&UE;6)E<E]N86UE(B!T;R`B)&1E<W1?;F%M92(N+BY=*3L**"1M96UB
M97(M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S=%]N86UE*2`]/2!!<F-H:79E
M.CI::7`Z.D%:7T]+*"DI"F]R(&1I92!Q<5M%<G)O<B!E>'1R86-T:6YG('II
M<"!M96UB97(@=&\@(B1D97-T7VYA;64B73L*8VAM;V0H,#4U-2P@)&1E<W1?
M;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*?0I]"GT*?0IU;FQE<W,@*"1005(Z
M.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*9&EE(#P\("(N(B!U;FQE<W,@0$%2
M1U8["E5S86=E.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;("U-;6]D
M=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*)#`@6R`M0GPM8B!=
M(%LM3V]U=&9I;&5=('-R8RYP87(*+@HD14Y6>U!!4E]04D]'3D%-17T@/2`D
M<')O9VYA;64@/2`D,"`]('-H:69T*$!!4D=6*3L*?0IS=6(@0W)E871E4&%T
M:"!["FUY("@D;F%M92D@/2!`7SL*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*
M;7D@*"1B87-E;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S96YA;64Z
M.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ)RDI.PIR97%U:7)E($9I;&4Z.E!A
M=&@["D9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE("1P871H
M*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R"GT*<W5B(')E<75I<F5?;6]D
M=6QE<R!["G)E<75I<F4@;&EB.PIR97%U:7)E($1Y;F%,;V%D97(["G)E<75I
M<F4@:6YT96=E<CL*<F5Q=6ER92!S=')I8W0["G)E<75I<F4@=V%R;FEN9W,[
M"G)E<75I<F4@=F%R<SL*<F5Q=6ER92!#87)P.PIR97%U:7)E($-A<G`Z.DAE
M879Y.PIR97%U:7)E($5R<FYO.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*
M<F5Q=6ER92!%>'!O<G1E<CL*<F5Q=6ER92!&8VYT;#L*<F5Q=6ER92!&:6QE
M.CI496UP.PIR97%U:7)E($9I;&4Z.E-P96,["G)E<75I<F4@6%-,;V%D97([
M"G)E<75I<F4@0V]N9FEG.PIR97%U:7)E($E/.CI(86YD;&4["G)E<75I<F4@
M24\Z.D9I;&4["G)E<75I<F4@0V]M<')E<W,Z.EIL:6(["G)E<75I<F4@07)C
M:&EV93HZ6FEP.PIR97%U:7)E($1I9V5S=#HZ4TA!.PIR97%U:7)E(%!!4CL*
M<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E(%!!4CHZ1&ES=#L*<F5Q=6ER
M92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["G)E<75I<F4@4$%2.CI&:6QT97(Z
M.E!A=&-H0V]N=&5N=#L*<F5Q=6ER92!A='1R:6)U=&5S.PIE=F%L('L@<F5Q
M=6ER92!#=V0@?3L*979A;"![(')E<75I<F4@5VEN,S(@?3L*979A;"![(')E
M<75I<F4@4V-A;&%R.CI5=&EL('T["F5V86P@>R!R97%U:7)E($%R8VAI=F4Z
M.E5N>FEP.CI"=7)S="!].PIE=F%L('L@<F5Q=6ER92!4:64Z.DAA<V@Z.DYA
M;65D0V%P='5R92!].PIE=F%L('L@<F5Q=6ER92!097)L24\[(')E<75I<F4@
M4&5R;$E/.CIS8V%L87(@?3L*979A;"![(')E<75I<F4@=71F."!].PI]"G-U
M8B!?<V5T7W!A<E]T96UP('L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'T@
M86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@>PHD<&%R7W1E;7`@/2`D
M,3L*<F5T=7)N.PI]"F9O<F5A8V@@;7D@)'!A=&@@*`HH;6%P("1%3E9[)%]]
M+"!Q=R@@4$%27U1-4$1)4B!435!$25(@5$5-4$1)4B!414U0(%1-4"`I*2P*
M<7<H($,Z7%Q414U0("]T;7`@+B`I"BD@>PIN97AT('5N;&5S<R!D969I;F5D
M("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@["FUY("1U<V5R;F%M
M93L*;7D@)'!W=6ED.PIE=F%L('LH)'!W=6ED*2`](&=E='!W=6ED*"0^*2!I
M9B!D969I;F5D("0^.WT["FEF("@@9&5F:6YE9"@F5VEN,S(Z.DQO9VEN3F%M
M92D@*2!["B1U<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE.PI]"F5L<VEF
M("AD969I;F5D("1P=W5I9"D@>PHD=7-E<FYA;64@/2`D<'=U:60["GT*96QS
M92!["B1U<V5R;F%M92`]("1%3E9[55-%4DY!345]('Q\("1%3E9[55-%4GT@
M?'P@)U-94U1%32<["GT*)'5S97)N86UE(#U^(',O7%<O7R]G.PIM>2`D<W1M
M<&1I<B`]("(D<&%T:"1S>7-[7V1E;&EM?7!A<BTB+G5N<&%C:R@B2"HB+"`D
M=7-E<FYA;64I.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*:68@*"$D14Y6>U!!
M4E]#3$5!3GT@86YD(&UY("1M=&EM92`]("AS=&%T*"1P<F]G;F%M92DI6SE=
M*2!["F]P96X@;7D@)&9H+"`B/#IR87<B+"`D<')O9VYA;64@;W(@9&EE('%Q
M6T-A;B=T(')E860@(B1P<F]G;F%M92(Z("0A73L*<V5E:R`D9F@L("TQ."P@
M,CL*;7D@)&)U9CL*<F5A9"`D9F@L("1B=68L(#8["FEF("@D8G5F(&5Q(")<
M,$-!0TA%(BD@>PIS965K("1F:"P@+34X+"`R.PIR96%D("1F:"P@)&)U9BP@
M-#$["B1B=68@/7X@<R]<,"\O9SL*)'-T;7!D:7(@+CT@(B1S>7-[7V1E;&EM
M?6-A8VAE+21B=68B.PI]"F5L<V4@>PIM>2`D9&EG97-T(#T@979A;`I["G)E
M<75I<F4@1&EG97-T.CI32$$["FUY("1C='@@/2!$:6=E<W0Z.E-(02T^;F5W
M*#$I.PIO<&5N(&UY("1F:"P@(CPZ<F%W(BP@)'!R;V=N86UE(&]R(&1I92!Q
M<5M#86XG="!R96%D("(D<')O9VYA;64B.B`D(5T["B1C='@M/F%D9&9I;&4H
M)&9H*3L*8VQO<V4H)&9H*3L*)&-T>"T^:&5X9&EG97-T.PI]('Q\("1M=&EM
M93L*)'-T;7!D:7(@+CT@(B1S>7-[7V1E;&EM?6-A8VAE+21D:6=E<W0B.PI]
M"F-L;W-E*"1F:"D["GT*96QS92!["B1%3E9[4$%27T-,14%.?2`](#$["B1S
M=&UP9&ER("X]("(D<WES>U]D96QI;7UT96UP+20D(CL*?0HD14Y6>U!!4E]4
M14U0?2`]("1S=&UP9&ER.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*;&%S=#L*
M?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM0
M05)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U8B!?<V%V95]A<R!["FUY("@D;F%M
M92P@)&-O;G1E;G1S+"`D;6]D92D@/2!`7SL*;7D@)&9U;&QN86UE(#T@(B1P
M87)?=&5M<"\D;F%M92(["G5N;&5S<R`H+64@)&9U;&QN86UE*2!["FUY("1T
M96UP;F%M92`]("(D9G5L;&YA;64N)"0B.PIM>2`D9F@["BAO<&5N("1F:"P@
M)SXZ<F%W)RP@)'1E;7!N86UE*0HF)B`H<')I;G0@)&9H("1C;VYT96YT<RD*
M)B8@*&-L;W-E("1F:"D*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@(B1T96UP
M;F%M92(Z("0A73L*8VAM;V0@)&UO9&4L("1T96UP;F%M92!I9B!D969I;F5D
M("1M;V1E.PIR96YA;64H)'1E;7!N86UE+"`D9G5L;&YA;64I(&]R('5N;&EN
M:R@D=&5M<&YA;64I.PI]"G)E='5R;B`D9G5L;&YA;64["GT*<W5B(%]S971?
M<')O9VYA;64@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@86YD
M("1%3E9[4$%27U!23T=.04U%?2`]?B`O*"XK*2\I('L*)'!R;V=N86UE(#T@
M)#$["GT*)'!R;V=N86UE('Q\/2`D,#L*:68@*"1%3E9[4$%27U1%35!](&%N
M9"!I;F1E>"@D<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2!["B1P
M<F]G;F%M92`]('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA;64L
M("1S>7-[7V1E;&EM?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%27U!23T=.04U%
M?2!O<B!I;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@/CT@,"D@>PII
M9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["G)E='5R;B!I9B`M
M<R`D9F@["GT*:68@*"US("(D<')O9VYA;64D<WES>U]E>&5](BD@>PHD<')O
M9VYA;64@+CT@)'-Y<WM?97AE?3L*<F5T=7)N.PI]"GT*9F]R96%C:"!M>2`D
M9&ER("AS<&QI="`O7%$D<WES>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(?2D@
M>PIN97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E<2`D
M14Y6>U!!4E]414U0?3L*)&1I<B`]?B!S+UQ1)'-Y<WM?9&5L:6U]7$4D+R\[
M"B@H)'!R;V=N86UE(#T@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64D<WES
M>U]E>&5](BDL(&QA<W0I"FEF("US("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N
M86UE)'-Y<WM?97AE?2(["B@H)'!R;V=N86UE(#T@(B1D:7(D<WES>U]D96QI
M;7TD<')O9VYA;64B*2P@;&%S="D*:68@+7,@(B1D:7(D<WES>U]D96QI;7TD
M<')O9VYA;64B.PI]"GT*<W5B(%]F:7A?<')O9VYA;64@>PHD,"`]("1P<F]G
M;F%M92!\?#T@)$5.5GM005)?4%)/1TY!345].PII9B`H:6YD97@H)'!R;V=N
M86UE+"`D<WES>U]D96QI;7TI(#P@,"D@>PHD<')O9VYA;64@/2`B+B1S>7-[
M7V1E;&EM?21P<F]G;F%M92(["GT*;7D@)'!W9"`]("AD969I;F5D("9#=V0Z
M.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D("97:6XS,CHZ
M1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*8VAO;7`H)'!W
M9"D["B1P<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1)'-Y<WM?9&5L:6U]7$4I
M+R1P=V0D<WES>U]D96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O
M9VYA;64["GT*<W5B(%]P87)?:6YI=%]E;G8@>PII9B`H("1%3E9[4$%27TE.
M251)04Q)6D5$?2LK(#T](#$@*2!["G)E='5R;CL*?2!E;'-E('L*)$5.5GM0
M05)?24Y)5$E!3$E:141](#T@,CL*?0IF;W(@*'%W*"!34$%73D5$(%1%35`@
M0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!344@*2`I('L*9&5L971E("1%3E9[
M(E!!4E\D7R)].PI]"F9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.($1%0E5'
M("\I('L*)$5.5GLB4$%27R1?(GT@/2`D14Y6>R)005)?1TQ/0D%,7R1?(GT@
M:68@97AI<W1S("1%3E9[(E!!4E]'3$]"04Q?)%\B?3L*?0II9B`H)$5.5GM0
M05)?5$5-4'TI('L*9&5L971E("1%3E9[4$%27T-,14%.?3L*?0I]"G-U8B!O
M=71S('L*<F5T=7)N(&EF("1Q=6EE=#L*:68@*"1L;V=F:"D@>PIP<FEN="`D
M;&]G9F@@(D!?7&XB.PI]"F5L<V4@>PIP<FEN="`B0%]<;B(["GT*?0IS=6(@
M:6YI=%]I;F,@>PIR97%U:7)E($-O;F9I9SL*<'5S:"!`24Y#+"!G<F5P(&1E
M9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*87)C:&QI8F5X
M<"!P<FEV;&EB97AP('-I=&5A<F-H97AP('-I=&5L:6)E>'`*=F5N9&]R87)C
M:&5X<"!V96YD;W)L:6)E>'`**3L*?0IP86-K86=E(&UA:6X["G)E<75I<F4@
M4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O
M<G0H0'!A<E]A<F=S*3L*9&EE('%Q6W!A<BYP;#H@0V%N)W0@;W!E;B!P97)L
M('-C<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R
M>5QN70IU;FQE<W,@+64@)'!R;V=N86UE.PID;R`D<')O9VYA;64["D-/4D4Z
M.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I
M92`D0"!I9B`D0#L*?3L*)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]"D-/4D4Z
M.F5X:70H)#$I(&EF("@D.CI?7T524D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI
M7"DO*3L*9&EE("0Z.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*,3L*7U]%3D1?
M7PH`<&5R;'AS:2YC`````````(FKS>\``````1L#.Q0````!````^)+__RP`
M````````$``````````#>E(``7P!`1L-`@`0````&````,22__\B``````<!
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````0````````#O`@````````$`````````
M_P(````````!``````````D#````````(`````````#8G0```````"$`````
M````"``````````9`````````."=````````&P`````````(`````````!H`
M````````Z)T````````<``````````@`````````]?[_;P````#8`@``````
M``4`````````.`T````````&`````````,`#````````"@````````"K!```
M``````L`````````&``````````5`````````````````````P````````!(
MH`````````(`````````6`4````````4``````````<`````````%P``````
M```@%0````````<`````````$!,````````(`````````&@'````````"0``
M```````8`````````!X`````````"`````````#[__]O``````$```@`````
M_O__;P````"P$@```````/___V\``````@````````#P__]O`````.01````
M````^?__;P`````+````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````#_____````````````````````````````````
M````````````````````````````````````````````````__________\`
M`````````(`:````````@!H```````"`&@```````(`:````````@!H`````
M``"`&@```````(`:````````@!H```````"`&@```````(`:````````@!H`
M``````"`&@```````(`:````````@!H```````"`&@```````(`:````````
M@!H```````"`&@```````(`:````````@!H```````"`&@```````(`:````
M````@!H```````"`&@```````(`:````````@!H```````"`&@```````(`:
M````````@!H```````"`&@```````(`:````````@!H```````"`&@``````
M`(`:````````@!H```````"`&@```````(`:````````@!H```````"`&@``
M`````(`:````````@!H```````"`&@```````(`:````````@!H```````"`
M&@```````(`:````````@!H```````"`&@```````(`:````````@!H`````
M``"`&@```````(`:````````@!H```````"`&@```````(`:````````@!H`
M``````"`&@```````/"=````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````1T-#.B`H56)U;G1U(#$Q+C,N
M,"TT=6)U;G1U,2D@,3$N,RXP`$$R````<FES8W8``2@````%<G8V-&DR<#!?
M;3)P,%]A,G`P7V8R<#!?9#)P,%]C,G`P```N<VAS=')T86(`+FEN=&5R<``N
M;F]T92YG;G4N8G5I;&0M:60`+FYO=&4N04))+71A9P`N9VYU+FAA<V@`+F1Y
M;G-Y;0`N9'EN<W1R`"YG;G4N=F5R<VEO;@`N9VYU+G9E<G-I;VY?<@`N<F5L
M82YD>6X`+G)E;&$N<&QT`"YT97AT`"YR;V1A=&$`+F5H7V9R86UE7VAD<@`N
M96A?9G)A;64`+G!R96EN:71?87)R87D`+FEN:71?87)R87D`+F9I;FE?87)R
M87D`+F1Y;F%M:6,`+F1A=&$`+F=O=``N8G-S`"YC;VUM96YT`"YR:7-C=BYA
M='1R:6)U=&5S````````````````````````````````````````````````
M````````````````````````````````````````"P````$````"````````
M`'`"````````<`(````````A`````````````````````0``````````````
M`````!,````'`````@````````"4`@```````)0"````````)```````````
M``````````0````````````````````F````!P````(`````````N`(`````
M``"X`@```````"`````````````````````$````````````````````-```
M`/;__V\"`````````-@"````````V`(```````#H``````````4`````````
M"````````````````````#X````+`````@````````#``P```````,`#````
M````>`D````````&`````@````@`````````&`````````!&`````P````(`
M````````.`T````````X#0```````*L$```````````````````!````````
M````````````3@```/___V\"`````````.01````````Y!$```````#*````
M``````4``````````@`````````"`````````%L```#^__]O`@````````"P
M$@```````+`2````````8``````````&`````@````@`````````````````
M``!J````!`````(`````````$!,````````0$P```````!`"````````!0``
M```````(`````````!@`````````=`````0```!"`````````"`5````````
M(!4```````!8!0````````4````5````"``````````8`````````'D````!
M````!@````````"`&@```````(`:````````L`,``````````````````!``
M````````$`````````!^`````0````8`````````,!X````````P'@``````
M`#8N```````````````````$````````````````````A`````$````"````
M`````&A,````````:$P```````"`0```````````````````"```````````
M`````````(P````!`````@````````#HC````````.B,````````%```````
M``````````````0```````````````````":`````0````(``````````(T`
M````````C0```````"P````````````````````(````````````````````
MI````!`````#`````````-B=````````V(T````````(````````````````
M`````0`````````(`````````+,````.`````P````````#@G0```````."-
M````````"`````````````````````@`````````"`````````"_````#P``
M``,`````````Z)T```````#HC0````````@````````````````````(````
M``````@`````````RP````8````#`````````/"=````````\(T````````0
M`@````````8`````````"``````````0`````````-0````!`````P``````
M````H`````````"0````````2`````````````````````@`````````````
M``````#:`````0````,`````````2*````````!(D````````$`"````````
M```````````(``````````@`````````WP````@````#`````````(BB````
M````B)(````````H$```````````````````"````````````````````.0`
M```!````,````````````````````(B2````````)0``````````````````
M``$``````````0````````#M`````P``<`````````````````````"MD@``
M`````#,````````````````````!`````````````````````0````,`````
M````````````````````X)(```````#_`````````````````````0``````
*````````````````
